==> jboss-eap-6.2.4-src.zip: jboss-eap-6.2-src/cli/src/main/java/org/jboss/as/cli/handlers/ifelse/GreaterThanOperation.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2011, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.as.cli.handlers.ifelse;

import org.jboss.as.cli.CommandLineException;


/**
 *
 * @author Alexey Loubyansky
 */
public class GreaterThanOperation extends ComparisonOperation {

    GreaterThanOperation() {
        super(ExpressionParser.GT);
    }

    @Override
    protected boolean compare(Object left, Object right) throws CommandLineException {
        if(left == null || right == null) {
            return false;
        }
        return ((Comparable<String>)left.toString()).compareTo(right.toString()) > 0;
    }
}

==> jboss-eap-6.4.10-src.zip: jboss-eap-6.4-src/cli/src/main/java/org/jboss/as/cli/handlers/ifelse/GreaterThanOperation.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2011, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.as.cli.handlers.ifelse;

/**
 *
 * @author Alexey Loubyansky
 */
public class GreaterThanOperation extends SameTypeOperation {

    static final String SYMBOL = ">";

    GreaterThanOperation() {
        super(SYMBOL);
    }

    @Override
    protected boolean doCompare(Object left, Object right) {
        if(left == null || right == null) {
            return false;
        }
        return ((Comparable<String>)left.toString()).compareTo(right.toString()) > 0;
    }
}
